#!/bin/bash

set -e

function usage() {
    echo -e "USAGE:
    $(basename $0) /path_ro_rootfs
    "

    exit 1
}

# 判断参数个数
if [ $# -ne 1 ]; then
    usage
fi

ROOTFS_DIR=$1

if [ ! -d ${ROOTFS_DIR} ]; then
    usage
fi

if [ "$(id -u)" != "0" ]; then
    CMD_MOUNT="sudo mount"
    CMD_UMOUNT="sudo umount"
    CMD_CHROOT="sudo chroot"
else
    CMD_MOUNT="mount"
    CMD_UMOUNT="umount"
    CMD_CHROOT="chroot"
fi

${CMD_UMOUNT} -l ${ROOTFS_DIR}/* >/dev/null 2>&1 || true

${CMD_MOUNT} --bind /dev ${ROOTFS_DIR}/dev
${CMD_MOUNT} --bind /run ${ROOTFS_DIR}/run
${CMD_MOUNT} -t devpts devpts ${ROOTFS_DIR}/dev/pts
${CMD_MOUNT} -t proc proc ${ROOTFS_DIR}/proc
${CMD_MOUNT} -t sysfs sysfs ${ROOTFS_DIR}/sys

# chroot并设置环境变量
${CMD_CHROOT} ${ROOTFS_DIR} /usr/bin/env -i \
    PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin \
    HOME=/root \
    LC_ALL=C \
    DEBIAN_FRONTEND=noninteractive \
    APT_KEY_DONT_WARN_ON_DANGEROUS_USAGE=DontWarn \
    /bin/bash --login +h

${CMD_UMOUNT} ${ROOTFS_DIR}/dev/pts
${CMD_UMOUNT} ${ROOTFS_DIR}/dev
${CMD_UMOUNT} ${ROOTFS_DIR}/run
${CMD_UMOUNT} ${ROOTFS_DIR}/sys
${CMD_UMOUNT} ${ROOTFS_DIR}/proc
