#!/bin/bash

set -e

function usage() {
  echo -e "USAGE:
    $(basename $0) --help   # 使用帮助
    $(basename $0) wifi     # 连接wifi
    $(basename $0) pxe      # pxe IP

    $(basename $0) build1   # 3台arm : 172.29.157.231 - 233
    $(basename $0) build2   # 3台龙芯: 172.29.157.234 - 236
    $(basename $0) build3   # 2台x86 : 172.29.157.237 - 238

    # 黄河大厦 16-20
    $(basename $0) work20   # 我的联想工作机器
    $(basename $0) work19   # 我的笔记本
    $(basename $0) work18
    $(basename $0) work17
    $(basename $0) work16   # 原 飞腾铁机器 241
    "
  exit 1
}

# 判断参数个数
if [ $# -eq 0 ]; then
  usage
  exit 1
fi

if [ "$1" == "wifi" ]; then
  # WIFI_SSID=kylin-gcjs-zz
  WIFI_SSID=asus
  if nmcli device wifi list | grep -q ${WIFI_SSID}; then
    # nmcli dev wifi connect ${WIFI_SSID} password gcjsqwe123
    nmcli dev wifi connect ${WIFI_SSID} password gcjsqwer1234
  fi
else
  GATEWAY="172.29.157.254"
  DNS1="172.20.191.2"
  DNS2="114.114.114.114"

  if [ "$1" == "pxe" ]; then
    IPADDR="10.0.0.10"
    GATEWAY="10.0.0.1"
    DNS1="10.0.0.10"
    DNS2="114.114.114.114"
  elif [ "$1" == "work20" ]; then
    IPADDR="172.29.157.20"
  elif [ "$1" == "work19" ]; then
    IPADDR="172.29.157.19"
  elif [ "$1" == "work18" ]; then
    IPADDR="172.29.157.18"
  elif [ "$1" == "work17" ]; then
    IPADDR="172.29.157.17"
  elif [ "$1" == "work16" ]; then
    IPADDR="172.29.157.16"
  elif [ "$1" == "dhcp" ]; then
    echo "自动分配"
  fi

  # 暂时以e开头为有线网卡判断条件，取最后一个网卡
  IFACE_LAN=$(LANG=en ip link | awk -F '[ :]' '{print $3}' | grep "^e" | tail -n 1)
  echo "IFACE_LAN=${IFACE_LAN}"

  source /etc/os-release

  if [ "${VERSION_CODENAME}" == "kylin" ]; then
    if [ "${KYLIN_RELEASE_ID}" == "2303" ]; then
      IF_NAME="有线连接 1"
    else
      # 2107
      IF_NAME="以太网连接 1"
    fi
  fi

  if [ -n "${DNS2}" ]; then
    nmcli c modify "${IF_NAME}" ifname "${IFACE_LAN}" ipv4.method manual ipv4.addr ${IPADDR}/24 ipv4.gateway ${GATEWAY} ipv4.dns "${DNS1},${DNS2}"
  else
    # ${IPADDR}/16
    nmcli c modify "${IF_NAME}" ifname "${IFACE_LAN}" ipv4.method manual ipv4.addr ${IPADDR}/22 ipv4.gateway ${GATEWAY} ipv4.dns "${DNS1}"
  fi

  # 使能网络
  nmcli c up "${IF_NAME}"
fi
