#!/bin/bash

KERNEL_DEBS=($(ls *.deb | grep -v dbg | grep -v linux-generic | grep -v linux-libc-dev))
for ((index = 0; index < ${#KERNEL_DEBS[@]}; index++)); do
    pkg=${KERNEL_DEBS[$index]}
    # dpkg-deb --info ${pkg} | sed -n "/Package:/,/Description:/p"
    PACKAGE=$(dpkg-deb --info "${pkg}" | grep "Package:" | awk '{print $2}')
    VERSION=$(dpkg-deb --info "${pkg}" | grep "Version:" | awk '{print $2}')
    if [[ ${pkg} =~ "linux-image" ]]; then
        ARCHITECTURE=$(dpkg-deb --info "${pkg}" | grep "Architecture:" | awk '{print $2}')
    fi

    if [[ ${index} == 0 ]]; then
        DEPENDS="${PACKAGE} (= ${VERSION})"
    else
        DEPENDS="${DEPENDS}, ${PACKAGE} (= ${VERSION})"
    fi
done

echo "ARCHITECTURE=${ARCHITECTURE}"
echo "VERSION=${VERSION}"
echo "DEPENDS=${DEPENDS}"

TARGET_SRC="linux-generic-${VERSION}"
rm -rf "${TARGET_SRC}"
mkdir -p "${TARGET_SRC}"/DEBIAN/
cat >"${TARGET_SRC}"/DEBIAN/control <<EOF
Package: linux-generic
Architecture: ${ARCHITECTURE}
Version: ${VERSION}
Depends: ${DEPENDS}
Maintainer: kylin <kylin@kylinos.cn>
Component: main
Section: kernel
Priority: optional
Description: Complete Generic Linux kernel and headers
 This package will always depend on the latest complete generic Linux kernel
 and headers.
EOF

package=$(grep "^Package: " "${TARGET_SRC}"/DEBIAN/control | awk '{print $2}')
version=$(grep "^Version: " "${TARGET_SRC}"/DEBIAN/control | awk '{print $2}')
architecture=$(grep "^Architecture: " "${TARGET_SRC}"/DEBIAN/control | awk '{print $2}')

dpkg -b "${TARGET_SRC}" "${package}_${version}_${architecture}".deb

rm -rf "${TARGET_SRC}"
