#!/bin/sh

if [ "$(id -u)" != "0" ]; then
    echo "please run as root" 1>&2
    exit 1
fi

usage() {
    echo "USAGE:
    $(basename "$0") /dev/sdb2  # device or mount point
    "

    exit 1
}

[ $# -ne 1 ] && usage

SGDISK=$(command -v sgdisk) || { echo "E: You must have sgdisk" && exit 1; }
PARTED=$(command -v parted) || { echo "E: You must have parted" && exit 1; }
PARTPROBE=$(command -v partprobe) || { echo "E: You must have partprobe" && exit 1; }
RESIZE2FS=$(command -v resize2fs) || { echo "E: You must have resize2fs" && exit 1; }

ROOT_DEVICE=$1

if [ -d "${ROOT_DEVICE}" ]; then
    # find device associate with the mount point
    ROOT_DEVICE=$(findmnt --noheadings --output=SOURCE "${ROOT_DEVICE}")
fi

ROOT_DEVICE=$(realpath "${ROOT_DEVICE}")

if [ ! -b "${ROOT_DEVICE}" ]; then
    echo "no device found!"
    exit 1
else
    echo "resize ${ROOT_DEVICE}"
fi

# find the block device
DEVICE=$(udevadm info --query=path --name="${ROOT_DEVICE}" | awk -F'/' '{print $(NF-1)}')
DEVICE="/dev/${DEVICE}"

# get the partition type
PART_TABLE_TYPE=$(udevadm info --query=property --name="${ROOT_DEVICE}" | grep '^ID_PART_TABLE_TYPE=' | cut -d'=' -f2)
if [ "$PART_TABLE_TYPE" = "gpt" ]; then
    ${SGDISK} -e "${DEVICE}" >/dev/null
    ${PARTPROBE}
fi

# get the partition number
PART_ENTRY_NUMBER=$(udevadm info --query=property --name="${ROOT_DEVICE}" | grep '^ID_PART_ENTRY_NUMBER=' | cut -d'=' -f2)
cat <<EOF | ${PARTED} ---pretend-input-tty "${DEVICE}"
resizepart ${PART_ENTRY_NUMBER} 100%
yes
-1MB
EOF

${PARTPROBE}
${RESIZE2FS} "${ROOT_DEVICE}" >/dev/null
